#!/bin/bash

TEST_DIR=`dirname $0`
BIN_DIR=$TEST_DIR/../bin
CONFIG=$TEST_DIR/hypertable.cfg

CLUSTER_CMD="$HYPERTABLE_HOME/bin/ht cluster -f ${HOME}/cluster.def ORIGIN_CONFIG_FILE=${CONFIG}"

function on_exit() {
  $CLUSTER_CMD destroy
  exit $RET
}

#trap on_exit EXIT

# Generate Hypertable config file
cp ~/hypertable.cfg $CONFIG

\rm -f $TEST_DIR/*.output

$CLUSTER_CMD dist
$CLUSTER_CMD push_config
$CLUSTER_CMD destroy
$CLUSTER_CMD start

sleep 5

export JAVA_HOME=/usr/java/latest

##
## issue 1264
##

# Fetch test INPUT data
if [ ! -e $TEST_DIR/pig-issue1264-data.tsv.gz ]; then
    wget -O $TEST_DIR/pig-issue1264-data.tsv.gz http://cdn.hypertable.com/pub/pig-issue1264-data.tsv.gz
fi


# Create table
$HYPERTABLE_HOME/bin/ht shell --batch --config=$CONFIG < $TEST_DIR/issue1264-create-table.hql
if [ $? != 0 ] ; then
   exit 1
fi

# Load data
echo "USE issue1264; LOAD DATA INFILE ROW_KEY_COLUMN=Key TIMESTAMP_COLUMN=QueryTime '$TEST_DIR/pig-issue1264-data.tsv.gz' INTO TABLE issue1264;" | \
    $HYPERTABLE_HOME/bin/ht shell --batch --config=$CONFIG

LIBTHRIFT_JAR=$HYPERTABLE_HOME/lib/java/libthrift.jar
HYPERTABLE_JAR=$HYPERTABLE_HOME/lib/java/hypertable.jar

#
# 2 <= ROW < 4
#
hadoop fs -rm -r issue1264
pig -Dpig.additional.jars=$HYPERTABLE_JAR:$LIBTHRIFT_JAR $TEST_DIR/issue1264a.pig
if [ $? != 0 ] ; then
    echo "Error encountered when running pig script 'issue1264a.pig'"
    exit 1
fi
echo "# 2 <= ROW < 4" >> $TEST_DIR/issue1264.output
hadoop fs -cat issue1264/part-m-00000 >> $TEST_DIR/issue1264.output

#
# 2 < ROW
#
hadoop fs -rm -r issue1264
pig -Dpig.additional.jars=$HYPERTABLE_JAR:$LIBTHRIFT_JAR $TEST_DIR/issue1264b.pig
if [ $? != 0 ] ; then
    echo "Error encountered when running pig script 'issue1264b.pig'"
    exit 1
fi
echo "# 2 < ROW" >> $TEST_DIR/issue1264.output
hadoop fs -cat issue1264/part-m-00000 >> $TEST_DIR/issue1264.output

#
# 2 <= ROW
#
hadoop fs -rm -r issue1264
pig -Dpig.additional.jars=$HYPERTABLE_JAR:$LIBTHRIFT_JAR $TEST_DIR/issue1264c.pig
if [ $? != 0 ] ; then
    echo "Error encountered when running pig script 'issue1264c.pig'"
    exit 1
fi
echo "# 2 <= ROW" >> $TEST_DIR/issue1264.output
hadoop fs -cat issue1264/part-m-00000 >> $TEST_DIR/issue1264.output

#
# ROW < 4
#
hadoop fs -rm -r issue1264
pig -Dpig.additional.jars=$HYPERTABLE_JAR:$LIBTHRIFT_JAR $TEST_DIR/issue1264d.pig
if [ $? != 0 ] ; then
    echo "Error encountered when running pig script 'issue1264d.pig'"
    exit 1
fi
echo "# ROW < 4" >> $TEST_DIR/issue1264.output
hadoop fs -cat issue1264/part-m-00000 >> $TEST_DIR/issue1264.output

#
# ROW <= 4
#
hadoop fs -rm -r issue1264
pig -Dpig.additional.jars=$HYPERTABLE_JAR:$LIBTHRIFT_JAR $TEST_DIR/issue1264e.pig
if [ $? != 0 ] ; then
    echo "Error encountered when running pig script 'issue1264e.pig'"
    exit 1
fi
echo "# ROW <= 4" >> $TEST_DIR/issue1264.output
hadoop fs -cat issue1264/part-m-00000 >> $TEST_DIR/issue1264.output

#
# 2 <= ROW <= 4
#
hadoop fs -rm -r issue1264
pig -Dpig.additional.jars=$HYPERTABLE_JAR:$LIBTHRIFT_JAR $TEST_DIR/issue1264f.pig
if [ $? != 0 ] ; then
    echo "Error encountered when running pig script 'issue1264f.pig'"
    exit 1
fi
echo "# 2 <= ROW <= 4" >> $TEST_DIR/issue1264.output
hadoop fs -cat issue1264/part-m-00000 >> $TEST_DIR/issue1264.output

#
# 2 < ROW < 4
#
hadoop fs -rm -r issue1264
pig -Dpig.additional.jars=$HYPERTABLE_JAR:$LIBTHRIFT_JAR $TEST_DIR/issue1264g.pig
if [ $? != 0 ] ; then
    echo "Error encountered when running pig script 'issue1264g.pig'"
    exit 1
fi
echo "# 2 < ROW < 4" >> $TEST_DIR/issue1264.output
hadoop fs -cat issue1264/part-m-00000 >> $TEST_DIR/issue1264.output

#
# 2 < ROW <= 4
#
hadoop fs -rm -r issue1264
pig -Dpig.additional.jars=$HYPERTABLE_JAR:$LIBTHRIFT_JAR $TEST_DIR/issue1264h.pig
if [ $? != 0 ] ; then
    echo "Error encountered when running pig script 'issue1264h.pig'"
    exit 1
fi
echo "# 2 < ROW <= 4" >> $TEST_DIR/issue1264.output
hadoop fs -cat issue1264/part-m-00000 >> $TEST_DIR/issue1264.output

#
# Diff output with golden file
#
diff $TEST_DIR/issue1264.output $TEST_DIR/issue1264.golden > $TEST_DIR/diff.output
if [ $? -ne 0 ]; then
  echo "Diff detected in 'issue1264' test output, exiting ..."
  exit 1
fi

exit 0

